@@ -3,7 +3,7 @@ use warnings;
 
 package JMAP::Tester;
 # ABSTRACT: a JMAP client made for testing JMAP servers
-$JMAP::Tester::VERSION = '0.010';
+$JMAP::Tester::VERSION = '0.011';
 use Moo;
 
 use Encode qw(encode_utf8);
@@ -17,9 +17,10 @@ use JMAP::Tester::Result::Failure;
 use JMAP::Tester::Result::Logout;
 use JMAP::Tester::Result::Upload;
 use Module::Runtime ();
-use Safe::Isa;
 use URI;
 
+use namespace::clean;
+
 #pod =head1 OVERVIEW
 #pod
 #pod B<Achtung!>  This library is in its really early days, so use it with that in
@@ -607,7 +608,7 @@ JMAP::Tester - a JMAP client made for testing JMAP servers
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 OVERVIEW
 
