@@ -2,7 +2,7 @@ use v5.10.0;
 
 package JMAP::Tester::Response;
 # ABSTRACT: what you get in reply to a succesful JMAP request
-$JMAP::Tester::Response::VERSION = '0.010';
+$JMAP::Tester::Response::VERSION = '0.011';
 use Moo;
 with 'JMAP::Tester::Role::Result';
 
@@ -10,6 +10,8 @@ use JMAP::Tester::Abort 'abort';
 use JMAP::Tester::Response::Sentence;
 use JMAP::Tester::Response::Paragraph;
 
+use namespace::clean;
+
 #pod =head1 OVERVIEW
 #pod
 #pod A JMAP::Tester::Response object represents the successful response to a JMAP
@@ -105,6 +107,27 @@ sub sentence {
   });
 }
 
+#pod =method sentences
+#pod
+#pod   my @sentences = $response->sentences;
+#pod
+#pod This method returns a list of all sentences in the response.
+#pod
+#pod =cut
+
+sub sentences {
+  my ($self) = @_;
+
+  my @sentences = map {;
+    JMAP::Tester::Response::Sentence->new({
+      triple       => $_,
+      _json_typist => $self->_json_typist
+    });
+  } @{ $self->_struct };
+
+  return @sentences;
+}
+
 #pod =method single_sentence
 #pod
 #pod   my $sentence = $response->single_sentence;
@@ -137,6 +160,59 @@ sub single_sentence {
   });
 }
 
+#pod =method sentence_named
+#pod
+#pod   my $sentence = $response->sentence_named($name);
+#pod
+#pod This method returns the sentence with the given name.  If no such sentence
+#pod exists, or if two sentences with the name exist, the tester will abort.
+#pod
+#pod =cut
+
+sub sentence_named {
+  my ($self, $name) = @_;
+
+  Carp::confess("no name given") unless defined $name;
+
+  my @sentences = grep {; $_->[0] eq $name } @{ $self->_struct };
+
+  unless (@sentences) {
+    abort(qq{no sentence found with name "$name"});
+  }
+
+  if (@sentences > 1) {
+    abort(qq{found more than one sentence with name "$name"});
+  }
+
+  return JMAP::Tester::Response::Sentence->new({
+    triple       => $sentences[0],
+    _json_typist => $self->_json_typist
+  });
+}
+
+#pod =method assert_n_sentences
+#pod
+#pod   my ($s1, $s2, ...) = $response->assert_n_sentences($n);
+#pod
+#pod This method returns all the sentences in the response, as long as there are
+#pod exactly C<$n>.  Otherwise, it aborts.
+#pod
+#pod =cut
+
+sub assert_n_sentences {
+  my ($self, $n) = @_;
+
+  Carp::confess("no sentence count given") unless defined $n;
+
+  my @sentences = $self->sentences;
+
+  unless (@sentences == $n) {
+    abort("expected $n sentences but got " . @sentences)
+  }
+
+  return @sentences;
+}
+
 #pod =method paragraph
 #pod
 #pod   my $para = $response->paragraph($n);
@@ -163,12 +239,42 @@ sub paragraph {
   });
 }
 
+#pod =method paragraphs
+#pod
+#pod   my @paragraphs = $response->paragraphs;
+#pod
+#pod This method returns a list of all paragraphs in the response.
+#pod
+#pod =cut
+
+sub paragraphs {
+  my ($self) = @_;
+
+  my @para_indices = @{ $self->_para_indices };
+
+  my @paragraphs;
+  for my $i_set (@para_indices) {
+    push @paragraphs, JMAP::Tester::Response::Paragraph->new({
+      sentences => [
+        map {;
+          JMAP::Tester::Response::Sentence->new({
+            triple => $_,
+            _json_typist => $self->_json_typist
+           }) } @{ $self->_struct }[ @$i_set ]
+      ],
+      _json_typist => $self->_json_typist,
+    });
+  }
+
+  return @paragraphs;
+}
+
 #pod =method assert_n_paragraphs
 #pod
 #pod   my ($p1, $p2, ...) = $response->assert_n_paragraphs($n);
 #pod
 #pod This method returns all the paragraphs in the response, as long as there are
-#pod exactly C<$n>.  Otherwise, it throws an exception.
+#pod exactly C<$n>.  Otherwise, it aborts.
 #pod
 #pod =cut
 
@@ -178,10 +284,12 @@ sub assert_n_paragraphs {
   Carp::confess("no paragraph count given") unless defined $n;
 
   my @para_indices = @{ $self->_para_indices };
-  if ($n and @para_indices != $n) {
+  unless ($n == @para_indices) {
     abort("expected $n paragraphs but got " . @para_indices)
   }
 
+  return unless $n;
+
   my $res = $self->_struct;
 
   my @sets;
@@ -292,7 +400,7 @@ JMAP::Tester::Response - what you get in reply to a succesful JMAP request
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 OVERVIEW
 
@@ -311,6 +419,12 @@ passed in the request.
 This method returns the I<n>th L<Sentence|JMAP::Tester::Response::Sentence> of
 the response.
 
+=head2 sentences
+
+  my @sentences = $response->sentences;
+
+This method returns a list of all sentences in the response.
+
 =head2 single_sentence
 
   my $sentence = $response->single_sentence;
@@ -321,6 +435,20 @@ the response, raising an exception if there's more than one Sentence.  If
 C<$name> is given, an exception is raised if the Sentence's name doesn't match
 the given name.
 
+=head2 sentence_named
+
+  my $sentence = $response->sentence_named($name);
+
+This method returns the sentence with the given name.  If no such sentence
+exists, or if two sentences with the name exist, the tester will abort.
+
+=head2 assert_n_sentences
+
+  my ($s1, $s2, ...) = $response->assert_n_sentences($n);
+
+This method returns all the sentences in the response, as long as there are
+exactly C<$n>.  Otherwise, it aborts.
+
 =head2 paragraph
 
   my $para = $response->paragraph($n);
@@ -328,12 +456,18 @@ the given name.
 This method returns the I<n>th L<Paragraph|JMAP::Tester::Response::Paragraph>
 of the response.
 
+=head2 paragraphs
+
+  my @paragraphs = $response->paragraphs;
+
+This method returns a list of all paragraphs in the response.
+
 =head2 assert_n_paragraphs
 
   my ($p1, $p2, ...) = $response->assert_n_paragraphs($n);
 
 This method returns all the paragraphs in the response, as long as there are
-exactly C<$n>.  Otherwise, it throws an exception.
+exactly C<$n>.  Otherwise, it aborts.
 
 =head2 paragraph_by_client_id
 
