@@ -1,11 +1,13 @@
 use v5.10.0;
 package JMAP::Tester::Response::Paragraph;
 # ABSTRACT: a group of sentences in a JMAP response
-$JMAP::Tester::Response::Paragraph::VERSION = '0.010';
+$JMAP::Tester::Response::Paragraph::VERSION = '0.011';
 use Moo;
 
 use JMAP::Tester::Abort 'abort';
 
+use namespace::clean;
+
 #pod =head1 OVERVIEW
 #pod
 #pod These objects represent paragraphs in the JMAP response.  That is, if your
@@ -96,6 +98,56 @@ sub single {
   return $sentences[0];
 }
 
+#pod =method assert_n_sentences
+#pod
+#pod   my ($s1, $s2, ...) = $paragraph->assert_n_sentences($n);
+#pod
+#pod This method returns all the sentences in the paragarph, as long as there are
+#pod exactly C<$n>.  Otherwise, it aborts.
+#pod
+#pod =cut
+
+sub assert_n_sentences {
+  my ($self, $n) = @_;
+
+  Carp::confess("no sentence count given") unless defined $n;
+
+  my @sentences = $self->sentences;
+
+  unless (@sentences == $n) {
+    abort("expected $n sentences but got " . @sentences)
+  }
+
+  return @sentences;
+}
+
+#pod =method sentence_named
+#pod
+#pod   my $sentence = $paragraph->sentence_named($name);
+#pod
+#pod This method returns the sentence with the given name.  If no such sentence
+#pod exists, or if two sentences with the name exist, the tester will abort.
+#pod
+#pod =cut
+
+sub sentence_named {
+  my ($self, $name) = @_;
+
+  Carp::confess("no name given") unless defined $name;
+
+  my @sentences = grep {; $_->name eq $name } $self->sentences;
+
+  unless (@sentences) {
+    abort(qq{no sentence found with name "$name"});
+  }
+
+  if (@sentences > 1) {
+    abort(qq{found more than one sentence with name "$name"});
+  }
+
+  return $sentences[0];
+}
+
 #pod =method as_struct
 #pod
 #pod =method as_stripped_struct
@@ -142,7 +194,7 @@ JMAP::Tester::Response::Paragraph - a group of sentences in a JMAP response
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 OVERVIEW
 
@@ -183,6 +235,20 @@ sentence doesn't have that name, an exception is raised.
 
 Otherwise, this method returns the sentence.
 
+=head2 assert_n_sentences
+
+  my ($s1, $s2, ...) = $paragraph->assert_n_sentences($n);
+
+This method returns all the sentences in the paragarph, as long as there are
+exactly C<$n>.  Otherwise, it aborts.
+
+=head2 sentence_named
+
+  my $sentence = $paragraph->sentence_named($name);
+
+This method returns the sentence with the given name.  If no such sentence
+exists, or if two sentences with the name exist, the tester will abort.
+
 =head2 as_struct
 
 =head2 as_stripped_struct
