@@ -1,9 +1,13 @@
 use v5.10.0;
 package JMAP::Tester::Response::Sentence;
 # ABSTRACT: a single triple within a JMAP response
-$JMAP::Tester::Response::Sentence::VERSION = '0.010';
+$JMAP::Tester::Response::Sentence::VERSION = '0.011';
 use Moo;
 
+use JMAP::Tester::Abort 'abort';
+
+use namespace::clean;
+
 #pod =head1 OVERVIEW
 #pod
 #pod These objects represent sentences in the JMAP response.  That is, if your
@@ -103,6 +107,27 @@ sub as_set {
   });
 }
 
+#pod =method assert_named
+#pod
+#pod   $sentence->assert_named("theName")
+#pod
+#pod This method aborts unless the sentence's name is the given name.  Otherwise, it
+#pod returns the sentence.
+#pod
+#pod =cut
+
+sub assert_named {
+  my ($self, $name) = @_;
+
+  Carp::confess("no name given") unless defined $name;
+
+  return $self if $self->name eq $name;
+
+  abort(
+    sprintf qq{expected sentence named "%s" but got "%s"}, $name, $self->name
+  );
+}
+
 1;
 
 __END__
@@ -117,7 +142,7 @@ JMAP::Tester::Response::Sentence - a single triple within a JMAP response
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 OVERVIEW
 
@@ -164,6 +189,13 @@ This method returns a L<JMAP::Tester::Response::Sentence::Set> object for the
 current sentence.  That's a specialized Sentence for C<setFoos>-style JMAP
 method responses.
 
+=head2 assert_named
+
+  $sentence->assert_named("theName")
+
+This method aborts unless the sentence's name is the given name.  Otherwise, it
+returns the sentence.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
