@@ -1,31 +1,21 @@
 use v5.10.0;
 package JMAP::Tester::Response::Sentence::Set;
 # ABSTRACT: the kind of sentence you get in reply to a setFoos call
-$JMAP::Tester::Response::Sentence::Set::VERSION = '0.010';
+$JMAP::Tester::Response::Sentence::Set::VERSION = '0.011';
 use Moo;
+extends 'JMAP::Tester::Response::Sentence';
 
 use Data::Dumper ();
 use JMAP::Tester::Abort 'abort';
 
+use namespace::clean;
+
 #pod =head1 OVERVIEW
 #pod
 #pod A "Set" sentence is a kind of L<Sentence|JMAP::Tester::Response::Sentence>
 #pod for representing C<foosSet> results.  It has convenience methods for getting
 #pod out the data returned in these kinds of sentences.
 #pod
-#pod =cut
-
-has name      => (is => 'ro', required => 1);
-has arguments => (is => 'ro', required => 1);
-has client_id => (is => 'ro', required => 1);
-
-has _json_typist => (
-  is => 'ro',
-  handles => {
-    _strip_json_types => 'strip_types',
-  },
-);
-
 #pod =method new_state
 #pod
 #pod This returns the C<newState> in the result.
@@ -93,6 +83,8 @@ sub old_state { $_[0]->arguments->{oldState} }
 #pod
 #pod =cut
 
+sub as_set { $_[0] }
+
 sub created { $_[0]->arguments->{created} }
 
 sub created_id {
@@ -190,7 +182,7 @@ JMAP::Tester::Response::Sentence::Set - the kind of sentence you get in reply to
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 OVERVIEW
 
